| Home | Libraries | People | FAQ | More

### has_trivial_move_constructor

    template <class T>
    struct has_trivial_move_constructor : public true_type-or-false_type {};

Inherits: If T is a (possibly cv-qualified) type with a trivial move-constructor then inherits from true_type, otherwise inherits from false_type.

If a type has a trivial move-constructor then the constructor has the same effect as copying the bits of one object to the other: calls to the constructor can be safely replaced with a call to `memcpy`.

Compiler Compatibility: If the compiler does not support partial-specialization of class templates, then this template can not be used with function types.

Without some (as yet unspecified) help from the compiler, has_trivial_move_constructor will never report that a user-defined class or struct has a trivial constructor; this is always safe, if possibly sub-optimal. Currently (February 2013) compilers have no necessary intrinsics to ensure that this trait "just works". You may also test to see if the necessary intrinsics are available by checking to see if the macro `BOOST_HAS_TRIVIAL_MOVE_CONSTRUCTOR` is defined.

Header: `#include <boost/type_traits/has_trivial_move_constructor.hpp>` or `#include <boost/type_traits.hpp>`

Examples:

> `has_trivial_move_constructor<int>` inherits from `true_type`.

> `has_trivial_move_constructor<char*>::type` is the type `true_type`.

> `has_trivial_move_constructor<int (*)(long)>::value` is an integral constant expression that evaluates to true.

> `has_trivial_move_constructor<MyClass>::value` is an integral constant expression that evaluates to false.

> `has_trivial_move_constructor<T>::value_type` is the type `bool`.